summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/variablewidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/variablewidget.h')
-rw-r--r--languages/cpp/debugger/variablewidget.h47
1 files changed, 25 insertions, 22 deletions
diff --git a/languages/cpp/debugger/variablewidget.h b/languages/cpp/debugger/variablewidget.h
index 5c77ea43..d56e8977 100644
--- a/languages/cpp/debugger/variablewidget.h
+++ b/languages/cpp/debugger/variablewidget.h
@@ -46,17 +46,18 @@ class GDBBreakpointWidget;
enum { VarNameCol = 0, ValueCol = 1, VarTypeCol = 2};
enum DataType { typeUnknown, typeValue, typePointer, typeReference,
- typeStruct, typeArray, typeQString, typeWhitespace,
+ typeStruct, typeArray, typeTQString, typeWhitespace,
typeName };
-class VariableWidget : public QWidget
+class VariableWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
VariableWidget( GDBController* controller,
GDBBreakpointWidget* breakpointWidget,
- TQWidget *parent=0, const char *name=0 );
+ TQWidget *tqparent=0, const char *name=0 );
VariableTree *varTree() const
{ return varTree_; }
@@ -82,11 +83,12 @@ private:
/***************************************************************************/
/***************************************************************************/
-class VariableTree : public KListView, public QToolTip
+class VariableTree : public KListView, public TQToolTip
{
Q_OBJECT
+ TQ_OBJECT
public:
- VariableTree(VariableWidget *parent,
+ VariableTree(VariableWidget *tqparent,
GDBController* controller,
GDBBreakpointWidget* breakpointWidget,
const char *name=0 );
@@ -184,16 +186,16 @@ private:
/***************************************************************************/
/***************************************************************************/
-/** List view item that can 'trim' outdated children.
+/** List view item that can 'trim' outdated tqchildren.
- The instances of this class hold a number of children corresponding
+ The instances of this class hold a number of tqchildren corresponding
to variables. When program state changes, such as after a step in source,
some variable values can change, and some variables can go out of scope.
We need
- highlight modified variables
- remove gone variables
- We could just remove all children and repopulate the list from
+ We could just remove all tqchildren and repopulate the list from
the data from debugger, but then we'd loose information about previous
variable values.
@@ -205,8 +207,8 @@ private:
class TrimmableItem : public KListViewItem
{
public:
- TrimmableItem(VariableTree *parent);
- TrimmableItem(TrimmableItem *parent);
+ TrimmableItem(VariableTree *tqparent);
+ TrimmableItem(TrimmableItem *tqparent);
virtual ~TrimmableItem();
@@ -226,17 +228,18 @@ class VarItem : public TQObject,
public TrimmableItem
{
Q_OBJECT
+ TQ_OBJECT
public:
enum format_t { natural, hexadecimal, decimal, character, binary };
/** Creates top-level variable item from the specified expression.
Optionally, alternative display name can be provided.
*/
- VarItem( TrimmableItem *parent,
+ VarItem( TrimmableItem *tqparent,
const TQString& expression,
bool frozen = false);
- VarItem( TrimmableItem *parent, const GDBMI::Value& varobj,
+ VarItem( TrimmableItem *tqparent, const GDBMI::Value& varobj,
format_t format, bool baseClassMember);
virtual ~VarItem();
@@ -283,7 +286,7 @@ public:
/** Recursively clears the varobjName_ field, making
*this completely disconnected from gdb.
- Automatically makes *this and children disables,
+ Automatically makes *this and tqchildren disables,
since there's no possible interaction with unhooked
object.
*/
@@ -297,7 +300,7 @@ public:
format_t formatFromGdbModifier(char c) const;
/** Clears highliting for this variable and
- all its children. */
+ all its tqchildren. */
void clearHighlight();
/** Sets new top-level textual value of this variable.
@@ -330,7 +333,7 @@ private:
- sets varobjName_ to 'name'
- sets format, if it's not default one
- gets initial value
- - if item is open, gets children.
+ - if item is open, gets tqchildren.
*/
void setVarobjName(const TQString& name);
@@ -345,12 +348,12 @@ private:
int column, int width, int align );
void varobjCreated(const GDBMI::ResultRecord& r);
void valueDone(const GDBMI::ResultRecord& r);
- void childrenDone(const GDBMI::ResultRecord& r);
- void childrenOfFakesDone(const GDBMI::ResultRecord& r);
+ void tqchildrenDone(const GDBMI::ResultRecord& r);
+ void tqchildrenOfFakesDone(const GDBMI::ResultRecord& r);
void handleCurrentAddress(const TQValueVector<TQString>& lines);
void handleType(const TQValueVector<TQString>& lines);
- void createChildren(const GDBMI::ResultRecord& r, bool children_of_fake);
+ void createChildren(const GDBMI::ResultRecord& r, bool tqchildren_of_fake);
/** Called to handle the output of the cli print command.
*/
@@ -370,7 +373,7 @@ private:
private:
// The gdb expression for this varItem relatively to
- // parent VarItem.
+ // tqparent VarItem.
TQString expression_;
bool highlight_;
@@ -388,7 +391,7 @@ private:
static int varobjIndex;
int numChildren_;
- bool childrenFetched_;
+ bool tqchildrenFetched_;
TQString currentAddress_;
TQString lastObtainedAddress_;
@@ -415,7 +418,7 @@ private:
class VarFrameRoot : public TrimmableItem
{
public:
- VarFrameRoot(VariableTree *parent, int frameNo, int threadNo);
+ VarFrameRoot(VariableTree *tqparent, int frameNo, int threadNo);
virtual ~VarFrameRoot();
void setOpen(bool open);
@@ -453,7 +456,7 @@ private:
class WatchRoot : public TrimmableItem
{
public:
- WatchRoot(VariableTree *parent);
+ WatchRoot(VariableTree *tqparent);
virtual ~WatchRoot();
};